// Библиотека iarduino_SensorPulse для работы с датчиком пульса, разработана интернет магазином http://iarduino.ru
// Ввод данных осуществляется через                    Датчик пульса http://iarduino.ru/shop/Sensory-Datchiki/datchik-pulsa.html
// Вывод данных осуществляется на                        TFT дисплей http://iarduino.ru/shop/Displei/cvetnoy-graficheskiy-displey-2-8-tft-320x240-uno-sensornyy.html
//                                                      Trema зуммер http://iarduino.ru/shop/Expansion-payments/zummer-trema-modul.html
// Для удобства подключения предлагаем воспользоваться Double Shield http://iarduino.ru/shop/Expansion-payments/double-shield.html
//                                                      Trema Shield http://iarduino.ru/shop/Expansion-payments/trema-shield.html

// Подключаем библиотеки:
#include <iarduino_SensorPulse.h>                          // подключаем библиотеку для работы с датчиком пульса
#include <UTFT.h>                                          // подключаем библиотеку для работы с TFT дисплеями

// Объявляем переменные и константы:
extern uint8_t       SmallFont[];
extern uint8_t       BigFont[];
const  uint16_t      colorBG = VGA_BLACK;                  // цвет фона
const  uint16_t      colorGR = VGA_GREEN;                  // цвет графика
const  uint16_t      colorCD = VGA_WHITE;                  // цвет текста и символа пульса
const  uint16_t      colorER = VGA_RED;                    // цвет текста об ошибке
       uint16_t      graphY0;                              // положение предыдущей точки графика по оси Y
       uint16_t      graphY;                               // положение текущей    точки графика по оси Y
       uint16_t      graphX;                               // положение текущей    точки графика по оси X
       uint16_t      screenW;                              // ширина дисплея
       uint16_t      screenH;                              // высота дисплея
UTFT                 myGLCD(TFT28UNO, A2,A1,A3,A4,A0);     // подключаем дисплей TFT28UNO
iarduino_SensorPulse Pulse(A5,1);                          // подключаем сенсор к 5 аналоговому входу, а зуммер к 1 цифровому выводу

void setup(){
   Pulse.begin();                                          // инициируем сенсор
   myGLCD.InitLCD();                                       // инициируем дисплей
   myGLCD.clrScr();                                        // стираем всю информацию с дисплея
   screenW = myGLCD.getDisplayXSize()-1;                   // получаем ширину дисплея
   screenH = myGLCD.getDisplayYSize()-1;                   // получаем высоту дисплея
}

/* описание функции check() библиотеки iarduino_SensorPulse
 * Pulse.check(ISP_ANALOG); - возвращает число от 0 до 1024 - данные с аналогового входа, к которому подключён датчик
 * Pulse.check(ISP_PULSE);  - возвращает число от 0 до 999  - пульс (количество пульсаций в минуту)
 * Pulse.check(ISP_BEEP);   - возвращает число от 0 до 2621 - количество десятых долей секунды, прошедшее после последнего пика пульса
 * Pulse.check(ISP_VALID);  - возвращает состояние датчика  - ISP_DISCONNECTED - отключён  (данные не соответствуют пульсу)
 *                                                            ISP_CONNECTED    - подключён (данные похожи на пульс)
 *                                                            ISP_CHANGED      - состояние сенсора изменилось (с подключён на отключён или наоборот)
 */

void loop(){
// определяем координаты текущей точки графика
   graphX++; if(graphX>=screenW){graphX=0;}                // сдвигаем   точку графика по оси X
   graphY = map(Pulse.check(ISP_ANALOG),1024,0,0,screenH); // определяем точку графика по оси Y
// если состояние сенсора изменилось, то ...
   if(Pulse.check(ISP_VALID)==ISP_CHANGED){
     myGLCD.clrScr();                                      // стираем всю информацию с дисплея
     graphX=0;                                             // сбрасываем координату текущей точки по оси X
   }
// если сенсор подключён, то ...
   if(Pulse.check(ISP_VALID)==ISP_CONNECTED){
//   выводим график
                                  myGLCD.setColor(colorBG); myGLCD.drawLine(graphX,  30,       graphX,  screenH );
       if(graphX>0){              myGLCD.setColor(colorGR); myGLCD.drawLine(graphX,  graphY0,  graphX,  graphY  );
                                  myGLCD.setColor(colorGR); myGLCD.drawLine(graphX-1,graphY0-1,graphX-1,graphY-1); // утолщаем линию
       }
//   выводим пульс и сердце
     if(Pulse.check(ISP_BEEP)==0){myGLCD.setColor(colorCD); myGLCD.fillCircle(20, 20, 4);}
     if(Pulse.check(ISP_BEEP)==1){myGLCD.setColor(colorBG); myGLCD.fillCircle(20, 20, 4);}
     if(Pulse.check(ISP_BEEP)==2){myGLCD.setColor(colorCD); myGLCD.setFont(SmallFont); myGLCD.printNumI(Pulse.check(ISP_PULSE),24,16,3);}
// иначе, если сенсор отключён, то выводим сообщение об ошибке
   }else                         {myGLCD.setColor(colorER); myGLCD.setFont(BigFont);   myGLCD.print("DISCONNECTED", CENTER,100);}
// присваиваем координату текущей точки графика, координате предыдущей точки
   graphY0 = graphY;
   delay(5);
}
